@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef SPECIALNOTIFIERJOB_H
-#define SPECIALNOTIFIERJOB_H
+#pragma once
 
 #include <Akonadi/KMime/MarkAsCommand>
 #include <Item>
@@ -38,6 +37,7 @@ private:
     void slotActivateNotificationAction(unsigned int index);
     void emitNotification(const QPixmap &pixmap = QPixmap());
     void deleteItemDone(KJob *job);
+    void slotReplyMessage();
     const QStringList mListEmails;
     QString mDefaultIconName;
     QString mSubject;
@@ -47,4 +47,3 @@ private:
     const Akonadi::Item::Id mItemId;
 };
 
-#endif // SPECIALNOTIFIERJOB_H
