@@ -49,7 +49,7 @@ void ObjectDeleteJob::davJobFinished(KJob *job)
         return;
     }
 
-    auto *davJob = qobject_cast<KIO::DavJob *>(job);
+    auto davJob = qobject_cast<KIO::DavJob *>(job);
 
     const QDomDocument document = davJob->response();
 
