@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef JOBS_H
-#define JOBS_H
+#pragma once
 
 #include <KIO/MetaData>
 #include <KJob>
@@ -184,4 +183,3 @@ private:
     uint mDataCounter;
 };
 
-#endif // JOBS_H
